# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discount/grpc/discount.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64iscount/grpc/discount.proto\x12\x10\x64\x61rsman.discount\x1a\x1cgoogle/protobuf/struct.proto\"=\n\rBasketRequest\x12,\n\x05items\x18\x01 \x03(\x0b\x32\x1d.darsman.discount.ItemRequest\"v\n\rCouponRequest\x12\x13\n\x0b\x63oupon_code\x18\x01 \x01(\t\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.darsman.discount.ItemRequest\x12\x15\n\x08owner_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_owner_id\"S\n\x18InstallmentBasketRequest\x12\x37\n\x05items\x18\x01 \x03(\x0b\x32(.darsman.discount.InstallmentItemRequest\"x\n\x16InstallmentItemRequest\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x11\n\titem_type\x18\x02 \x01(\t\x12\x16\n\x0eupfront_amount\x18\x03 \x01(\x05\x12\x13\n\x0bpart_amount\x18\x04 \x01(\x05\x12\r\n\x05parts\x18\x05 \x01(\x05\"@\n\x0bItemRequest\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x11\n\titem_type\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\x05\"o\n\x08Response\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"\'\n\x15TieredDiscountRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\"i\n\x0cUsageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0f\x64iscount_amount\x18\x02 \x01(\x05\x12\x13\n\x06\x63oupon\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07\x62\x61skets\x18\x04 \x03(\tB\t\n\x07_coupon2\xd0\x03\n\x12\x44iscountController\x12\x63\n\x17\x43\x61lcInstallmentByBasket\x12*.darsman.discount.InstallmentBasketRequest\x1a\x1a.darsman.discount.Response\"\x00\x12R\n\x11\x43\x61lculateByBasket\x12\x1f.darsman.discount.BasketRequest\x1a\x1a.darsman.discount.Response\"\x00\x12R\n\x11\x43\x61lculateByCoupon\x12\x1f.darsman.discount.CouponRequest\x1a\x1a.darsman.discount.Response\"\x00\x12`\n\x17\x43\x61lculateTieredDiscount\x12\'.darsman.discount.TieredDiscountRequest\x1a\x1a.darsman.discount.Response\"\x00\x12K\n\x0b\x43reateUsage\x12\x1e.darsman.discount.UsageRequest\x1a\x1a.darsman.discount.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discount.grpc.discount_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BASKETREQUEST']._serialized_start=80
  _globals['_BASKETREQUEST']._serialized_end=141
  _globals['_COUPONREQUEST']._serialized_start=143
  _globals['_COUPONREQUEST']._serialized_end=261
  _globals['_INSTALLMENTBASKETREQUEST']._serialized_start=263
  _globals['_INSTALLMENTBASKETREQUEST']._serialized_end=346
  _globals['_INSTALLMENTITEMREQUEST']._serialized_start=348
  _globals['_INSTALLMENTITEMREQUEST']._serialized_end=468
  _globals['_ITEMREQUEST']._serialized_start=470
  _globals['_ITEMREQUEST']._serialized_end=534
  _globals['_RESPONSE']._serialized_start=536
  _globals['_RESPONSE']._serialized_end=647
  _globals['_TIEREDDISCOUNTREQUEST']._serialized_start=649
  _globals['_TIEREDDISCOUNTREQUEST']._serialized_end=688
  _globals['_USAGEREQUEST']._serialized_start=690
  _globals['_USAGEREQUEST']._serialized_end=795
  _globals['_DISCOUNTCONTROLLER']._serialized_start=798
  _globals['_DISCOUNTCONTROLLER']._serialized_end=1262
# @@protoc_insertion_point(module_scope)
